import React, {
    useContext
} from "react";

import {
    getChampionshipPosition,
    getPointsAheadMax,
    getPointsAheadMin,
    getPointsAvailableForRace,
    getPointsAvailableFromRace,
    getRacesLeft
} from "../utility/champCalculator";
import {
    YearContext
} from "../pages/YearRoute";

function DriverComparisonTable({ driver1, driver2 }) {
    const {
        points,
        year
    } = useContext(YearContext);
    if(!points) {
        return null;
    }

    const racesLeft = getRacesLeft(year);
    const driver1Position = getChampionshipPosition(year, driver1);
    const driver1Points = points.drivers[driver1];
    const driver2Points = points.drivers[driver2];

    const pointsFromRace = getPointsAvailableFromRace(year);
    const isPosition = (driver1Points - driver2Points) > pointsFromRace

    return (
        <table className="table table-bordered">
            <thead>
            <tr>
                <th>Race</th>
                <th className="text-end">Max points</th>
                <th className="text-end">Difference after { driver2 } no points</th>
                <th className="text-end">Difference after { driver2 } P2 finish</th>
                <th className="text-end">Points left after</th>
                <th>Possible outcome</th>
            </tr>
            </thead>
            <tbody>
            <tr className={ isPosition ? "table-success" : "" }>
                <td>Current</td>
                <td/>
                <td/>
                <td className="text-end">{ driver1Points - driver2Points }</td>
                <td className="text-end">{ pointsFromRace }</td>
                <td>
                    { isPosition && (
                        driver1Position === 1 ? (
                            driver1 + " is champion"
                        ) : (
                            driver1 + " is P" + driver1Position + " in championship"
                        )
                    )}
                </td>
            </tr>
            { racesLeft.map((race, raceIndex) => {
                const racePoints = getPointsAvailableForRace(race);
                const pointsLeft = getPointsAvailableFromRace(year, race);
                const pointsAheadMax = getPointsAheadMax(year, driver1, driver2, race);
                const pointsAheadMin = getPointsAheadMin(year, driver1, driver2, race);
                const wouldBePosition = pointsAheadMax > pointsLeft;
                const couldBePosition = pointsAheadMin > pointsLeft;
                return (
                    <tr key={ raceIndex } className={ wouldBePosition ? "table-success" : (couldBePosition ? "table-warning" : "table-danger") }>
                        <td>{ race.name }</td>
                        <td className="text-end">{ racePoints }</td>
                        <td className="text-end">{ pointsAheadMin }</td>
                        <td className="text-end">{ pointsAheadMax }</td>
                        <td className="text-end">{ pointsLeft }</td>
                        <td>
                            { isPosition ? (
                                driver1Position === 1 ? (
                                    driver1 + " is champion"
                                ) : (
                                    driver1 + " is P" + driver1Position + " in championship"
                                )
                            ) : wouldBePosition ? (
                                driver1Position === 1 ? (
                                    driver1 + " would be champion"
                                ) : (
                                    driver1 + " would be P" + driver1Position + " in championship"
                                )
                            ) : couldBePosition ? (
                                driver1Position === 1 ? (
                                    driver1 + " could be champion"
                                ) : (
                                    driver1 + " could be P" + driver1Position + " in championship"
                                )
                            ) : (
                                "Not decided"
                            )}
                        </td>
                    </tr>
                )
            })}
            </tbody>
        </table>
    )
}

export default React.memo(DriverComparisonTable);
