import React, {
    useContext,
    useMemo
} from "react";
import {
    Link,
    useRouteMatch
} from "react-router-dom";

import DriverComparison from "../components/DriverComparison";

import {
    YearContext
} from "./YearRoute";

function DriverChip({ driver, points }) {
    const { year } = useContext(YearContext);
    const url = `/${year}/drivers/${ driver.toLowerCase() }`;
    const match = useRouteMatch({
        path: url,
        exact: true
    });

    const className = useMemo(() => {
        let classNames = ["btn rounded-pill me-2 mb-2"];
        if (match) {
            classNames.push("btn-primary");
        } else {
            classNames.push("bg-danger-subtle border-danger text-danger-emphasis");
        }
        return classNames.join(" ")
    }, [match]);

    return (
        <Link
            to={ url }
            className={ className }
        >
            { driver.toUpperCase() } { points }
        </Link>
    );
}

function Driver({ match }) {
    const {
        points
    } = useContext(YearContext);
    if(!points) {
        return null;
    }

    const driver = match.params.driver?.toUpperCase();

    return (
        <div className="container mt-3">
            <div className="my-3">
                { Object.entries(points.drivers).map(([driverList, points]) => (
                    <DriverChip
                        key={ driverList }
                        driver={ driverList }
                        points={ points }
                    />
                ))}
            </div>

            { !driver ? (
                <div className="text-center">
                    <h2>
                        Select a driver above
                    </h2>
                </div>
            ) : (
                <DriverComparison
                    driver={ driver }
                />
            )}
        </div>
    );
}

export default React.memo(Driver);
