import React, {useContext} from "react";

import {
    getPointsAvailableForRace,
    getRacesLeft,
    getTotalPointsLeft
} from "../utility/champCalculator";

import {
    YearContext
} from "./YearRoute";

function Races() {
    const {
        races,
        year
    } = useContext(YearContext);
    const racesLeft = getRacesLeft(year);
    const pointsLeft = getTotalPointsLeft(year);
    if(!races) {
        return (
            <div className="container mt-3">

            </div>
        );
    }
    return (
        <div className="container mt-3">
            <h1>Races</h1>
            <p>
                <b>
                    Total points left to gain: { pointsLeft }
                </b>
            </p>
            <table className="table table-bordered">
                <thead>
                <tr>
                    <th/>
                    <th>Race</th>
                    <th>Points</th>
                </tr>
                </thead>
                <tbody>
                { races?.map((race, index) => {
                    const left = racesLeft.includes(race);
                    const nextUp = race === racesLeft[0];
                    let className = "table-success";
                    if(nextUp) {
                        className = "table-info";
                    } else if(left) {
                        className = "table-danger";
                    }
                    return (
                        <tr key={ index } className={ className }>
                            <td>
                                { nextUp ? (
                                    "Next up"
                                ) : left ? (
                                    "Remaining"
                                ) : (
                                    "Done"
                                )}
                            </td>
                            <td>{ race.name }</td>
                            <td>{ getPointsAvailableForRace(race) }</td>
                        </tr>
                    )
                })}
                </tbody>
            </table>
        </div>
    )
}

export default React.memo(Races);
