import React, {
    useEffect,
    useMemo,
    useState
} from "react";
import moment from "moment";
import {
    Redirect,
    Route,
    Switch,
    useParams
} from "react-router-dom";

import Races from "./Races";
import Driver from "./Driver";
import Team from "./Team";

import teams2023 from "../data/2023/teams.json";
import races2023 from "../data/2023/races.json";
import points2023 from "../data/2023/points.json";

import teams2024 from "../data/2024/teams.json";
import races2024 from "../data/2024/races.json";
import points2024 from "../data/2024/points.json";

export function getData() {
    return {
        2023: {
            teams: teams2023,
            races: races2023,
            points: points2023,
        },
        2024: {
            teams: teams2024,
            races: races2024,
            points: points2024,
        }
    }
}

export const YearContext = React.createContext(null);

function YearRoute() {
    const {
        year
    } = useParams();
    const [teams, setTeams] = useState(undefined);
    const [races, setRaces] = useState(undefined);
    const [points, setPoints] = useState(undefined);

    const selectedYear = useMemo(() => {
        const currentYear = moment().year();
        const parsedYear = year ? parseInt(year) : null;
        if(!parsedYear) {
            return currentYear;
        }
        return parsedYear;
    }, [year]);

    useEffect(() => {
        const update = async () => {
            if (!year) {
                setTeams(null);
                setRaces(null);
                setPoints(null);
            }
            const data = await getData();
            setTeams(data[year].teams);
            setRaces(data[year].races);
            setPoints(data[year].points);
        }
        update();
    }, [year]);

    return (
        <YearContext.Provider value={{
            teams,
            races,
            points,
            year: selectedYear
        }}>
            <Switch>
                <Route
                    path={`/${selectedYear}/races`}
                    exact
                    component={ Races }
                />
                <Route
                    path={ [`/${selectedYear}/drivers/:driver`, `/${selectedYear}/drivers`] }
                    exact
                    component={ Driver }
                />
                <Route
                    path={ [`/${selectedYear}/teams/:team`, `/${selectedYear}/teams`] }
                    exact
                    component={ Team }
                />
                <Route path="/">
                    <Redirect to={`/${selectedYear}/races`}/>
                </Route>
            </Switch>
        </YearContext.Provider>
    )
}

export default React.memo(YearRoute);
