import {
    getData
} from "../pages/YearRoute";

export function getPointsAvailableForRace(race, firstPlace = true) {
    if(race.gp) {
        return 26 - (firstPlace ? 0 : 8);
    } else if(race.sprint) {
        return 8 - (firstPlace ? 0 : 1);
    }
}

export function getRacesLeft(year) {
    const data = getData()[year];
    const lastRaceIndex = data.points.updatedUntil;
    return data.races.filter((race, index) => {
        return index >= lastRaceIndex;
    })
}

export function getTotalPointsLeft(year) {
    const racesLeft = getRacesLeft(year);
    let totalPoints = 0;
    racesLeft.forEach((race) => {
        totalPoints += getPointsAvailableForRace(race);
    })
    return totalPoints;
}

export function getPointsAvailableFromRace(year, targetRace = null) {
    let pointsAvailable = getTotalPointsLeft(year);
    if(!targetRace) {
        return pointsAvailable;
    }
    const racesLeft = getRacesLeft(year);
    for(const race of racesLeft) {
        pointsAvailable -= getPointsAvailableForRace(race);
        if(race.name === targetRace.name) {
            break;
        }
    }
    return pointsAvailable;
}

export function getPointsAheadMax(year, driver1, driver2, targetRace) {
    const data = getData()[year];
    const racesLeft = getRacesLeft(year);
    let pointsDriver1 = data.points.drivers[driver1];
    let pointsDriver2 = data.points.drivers[driver2];
    for(const race of racesLeft) {
        pointsDriver1 += getPointsAvailableForRace(race, true);
        pointsDriver2 += getPointsAvailableForRace(race, false);
        if(targetRace && race.name === targetRace.name) {
            break;
        }
    }
    return pointsDriver1 - pointsDriver2;
}

export function getPointsAheadMin(year, driver1, driver2, targetRace) {
    const data = getData()[year];
    const racesLeft = getRacesLeft(year);
    let pointsDriver1 = data.points.drivers[driver1];
    let pointsDriver2 = data.points.drivers[driver2];
    for(const race of racesLeft) {
        pointsDriver1 += getPointsAvailableForRace(race, true);
        if(targetRace && race.name === targetRace.name) {
            break;
        }
    }
    return pointsDriver1 - pointsDriver2;
}

export function getChampionshipPosition(year, driver) {
    const data = getData()[year];
    const drivers = Object.entries(data.points.drivers);
    drivers.sort((a, b) => {
        return b[1] - a[1];
    })
    return drivers.findIndex((driverPoints) => {
        return driverPoints[0] === driver;
    }) + 1;
}

export function getTeamPoints(year, team) {
    const data = getData()[year];
    const teamData = data.teams[team];
    let teamPoints = 0;
    for(const driver of teamData.drivers) {
        teamPoints += data.points.drivers[driver];
    }
    return teamPoints;
}
